@@ -3,7 +3,10 @@ from datasets import load_dataset
 from datasets.dataset_dict import DatasetDict
 from transformers import Wav2Vec2Processor
 from conversationalnlp.utils import display
+from typing import Tuple
 import soundfile as sf
+import numpy as np
+import librosa
 import logging
 import re
 import os
@@ -27,12 +30,18 @@ class Wav2Vec2Dataset:
     TODO: remove rows with audio length > n seconds/word count > n
 
     """
+    __samplerate = 16000
 
     chars_to_ignore_regex = '[\,\?\.\!\-\;\:\"]'
 
     def __init__(self):
         pass
 
+    @property
+    def samplerate(self):
+
+        return self.__samplerate
+
     def loadHFdataset(self, dataset: DatasetDict):
         """
         Attributes
@@ -92,6 +101,7 @@ class Wav2Vec2Dataset:
                 logging.error(f"{batch['file']} not available")
 
             else:
+                # under the assumption all audio are sample at 16kHz
                 audio, samplerate = sf.read(batch['file'])
 
         # batched output is "un-batched" to ensure mapping is correct
@@ -147,16 +157,27 @@ class Wav2Vec2Dataset:
             return None
 
         else:
-            audio, samplerate = sf.read(audiopath)
 
-            np_audio = modelloader.processor(
-                audio, sampling_rate=samplerate).input_values[0]
+            np_audio, samplerate = self.loadaudio(audiopath)
+
+            processed_np_audio = modelloader.processor(
+                np_audio, sampling_rate=samplerate).input_values[0]
 
             tensor_audio = torch.tensor(
-                [np_audio.tolist()], device=modelloader.device)
+                [processed_np_audio.tolist()], device=modelloader.device)
 
             return tensor_audio
 
+    def loadaudio(self, audiopath: str) -> Tuple[np.array, int]:
+        audio, inputsamplerate = sf.read(audiopath)
+
+        if inputsamplerate != self.samplerate:
+            # resample
+            audio = librosa.resample(
+                audio, orig_sr=inputsamplerate, target_sr=self.samplerate)
+
+        return (audio, self.samplerate)
+
     def _normalizetext(self, dataset: DatasetDict) -> DatasetDict:
         """
         Normalize text 
